# f-line-merger

This package provides a simple line merger gui

## Installation

You can install the package using pip:

```bash
pip install f-line-merger
```

## Usage

To execute the `f-line-merger` command:

```bash
f-line-merger
```

This command will execute the gui app.
